@@ -34,9 +34,6 @@ import lalinference.tiger.omegascans_dag
 print("import: 'lalinference.tiger.postproc'")
 import lalinference.tiger.postproc
 
-print("import: 'lalinference.util.file'")
-import lalinference.util.file
-
 print("import: 'lalinference.wrapper'")
 import lalinference.wrapper
 
